DeviceUpdate class

Annotations
  • @freezed

Constructors

DeviceUpdate({required Device device, required String deviceId, int? numUsers})
factory
DeviceUpdate.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $DeviceUpdateCopyWith<DeviceUpdate>
Create a copy of DeviceUpdate with the given fields replaced by the non-null parameter values.
no setterinherited
device → Device
no setterinherited
deviceId → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
numUsers → int?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this DeviceUpdate to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited