Key class

Annotations
  • @unfreezed

Constructors

Key({String? certificateRequest, String? keyTimestamp, required String publicKey})
factory
Key.fromJson(Map<String, dynamic> json)
factory

Properties

certificateRequest ↔ String?
getter/setter pairinherited
copyWith → $KeyCopyWith<Key>
Create a copy of Key with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
keyTimestamp ↔ String?
getter/setter pairinherited
publicKey ↔ String
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Key to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited