Nv class

Annotations
  • @freezed

Constructors

Nv({required String name, String? value})
factory
Nv.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $NvCopyWith<Nv>
Create a copy of Nv with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Nv to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited