PageInfo class

Annotations
  • @freezed

Constructors

PageInfo({Cursor? cursor, required bool hasNextPage, required bool hasPreviousPage})
factory
PageInfo.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PageInfoCopyWith<PageInfo>
Create a copy of PageInfo with the given fields replaced by the non-null parameter values.
no setterinherited
cursor → Cursor?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNextPage → bool
no setterinherited
hasPreviousPage → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this PageInfo to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited