Space class

Annotations
  • @freezed

Constructors

Space({List<UserRef?>? admins, SpaceAppsConnection? apps, String? certificate, String? cookbook, String? domainName, String? fqdn, String? iaas, String? ipAddress, bool? isEgressNode, AWSTimestamp? lastSeen, String? localCaRoot, int? meshNetworkBitmask, IPType? meshNetworkType, Org? org, UserRef? owner, int? port, String? publicKey, String? recipe, String? region, String? settings, required String spaceId, String? spaceName, SpaceStatus? status, SpaceUsersConnection? users, String? version, String? vpnType})
factory
Space.fromJson(Map<String, dynamic> json)
factory

Properties

admins → List<UserRef?>?
no setterinherited
apps → SpaceAppsConnection?
no setterinherited
certificate → String?
no setterinherited
cookbook → String?
no setterinherited
copyWith → $SpaceCopyWith<Space>
Create a copy of Space with the given fields replaced by the non-null parameter values.
no setterinherited
domainName → String?
no setterinherited
fqdn → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
iaas → String?
no setterinherited
ipAddress → String?
no setterinherited
isEgressNode → bool?
no setterinherited
lastSeen → int?
no setterinherited
localCaRoot → String?
no setterinherited
meshNetworkBitmask → int?
no setterinherited
meshNetworkType → IPType?
no setterinherited
org → Org?
no setterinherited
owner → UserRef?
no setterinherited
port → int?
no setterinherited
publicKey → String?
no setterinherited
recipe → String?
no setterinherited
region → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → String?
no setterinherited
spaceId → String
no setterinherited
spaceName → String?
no setterinherited
status → SpaceStatus?
no setterinherited
users → SpaceUsersConnection?
no setterinherited
version → String?
no setterinherited
vpnType → String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes this Space to a JSON map.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited